@@ -251,7 +251,16 @@ class JobBase(abc.ABC):
         :raise RuntimeError: if this method is called multiple times or if
             reading from cache file fails unexpectedly
         """
-        if self.is_enabled:
+        if self.is_finished:
+            # This happens if another jobs fails before this job is started and
+            # the job manager (e.g. tui.TUI) finishes all jobs before it handles
+            # the error from the failed job.
+            _log.debug('%s: Not executing already finished job', self.name)
+        elif not self.is_enabled:
+            # Job is waiting for another job (see `prejobs` property) or for a
+            # condition (see `condition` property)
+            _log.debug('%s: Not executing disabled job', self.name)
+        else:
             if self._is_started:
                 raise RuntimeError('start() was already called')
             else:
@@ -271,8 +280,6 @@ class JobBase(abc.ABC):
                 self._is_executed = True
                 self.execute()
                 self.signal.emit('executed', self)
-        else:
-            _log.debug('%s: Disabled', self.name)
 
     @property
     def is_started(self):
