@@ -26,11 +26,7 @@ class SceneSearchJob(JobBase):
     name = 'scene-search'
     label = 'Scene Search'
     hidden = True
-
-    @property
-    def cache_id(self):
-        """Final segment of `content_path`"""
-        return fs.basename(self._content_path)
+    cache_id = None  # Don't cache output
 
     def initialize(self, *, content_path, predb=None):
         """
@@ -85,19 +81,15 @@ class SceneCheckJob(JobBase):
             :class:`~.types.SceneCheckResult` enum as a positional argument.
 
         ``checked``
-            Emitted after the user decided whether it's a scene release or not.
-            Registered callbacks get a :class:`~.utils.types.SceneCheckResult`
-            enum as a positional argument.
+            Emitted after :attr:`is_scene_release` is set. Registered callbacks
+            get a :class:`~.utils.types.SceneCheckResult` enum as a positional
+            argument.
     """
 
     name = 'scene-check'
     label = 'Scene Check'
     hidden = False
-
-    @property
-    def cache_id(self):
-        """Final segment of `content_path`"""
-        return fs.basename(self._content_path)
+    cache_id = None  # Don't cache output
 
     @property
     def content_stem(self):
