@@ -4,8 +4,7 @@ Share generated metadata
 
 import asyncio
 
-from .. import errors
-from ..trackers.base import TrackerBase, TrackerJobsBase
+from .. import errors, trackers
 from . import JobBase
 
 import logging  # isort:skip
@@ -60,8 +59,8 @@ class SubmitJob(JobBase):
         :param TrackerJobsBase tracker_jobs: Instance of
             :attr:`~.base.TrackerBase.TrackerJobs`
         """
-        assert isinstance(tracker, TrackerBase), f'Not a TrackerBase: {tracker!r}'
-        assert isinstance(tracker_jobs, TrackerJobsBase), f'Not a TrackerJobsBase: {tracker_jobs!r}'
+        assert isinstance(tracker, trackers.TrackerBase), f'Not a TrackerBase: {tracker!r}'
+        assert isinstance(tracker_jobs, trackers.TrackerJobsBase), f'Not a TrackerJobsBase: {tracker_jobs!r}'
         for t in (tracker, tracker_jobs):
             t.signal.register('warning', self.warn)
             t.signal.register('error', self.error)
