@@ -570,8 +570,8 @@ class TrackerJobsBase(abc.ABC):
         """
         :class:`~.jobs.screenshots.ScreenshotsJob` instance
 
-        The number of screenshots to make is taken from the "--screenshots" CLI
-        argument, if present and non-falsy, and defaults to :attr:`screenshots`.
+        The number of screenshots to make is taken from the ``screenshots``
+        value in :attr:`options`.
         """
         return jobs.screenshots.ScreenshotsJob(
             content_path=self.content_path,
