@@ -52,12 +52,17 @@ class DummyTrackerConfig(base.TrackerConfigBase):
 
 
 class DummyTrackerJobs(base.TrackerJobsBase):
+
+    torrent_piece_size_min = 4 * 2**20  # 4 MiB
+    torrent_piece_size_max = 8 * 2**20  # 8 MiB
+
     @cached_property
     def jobs_before_upload(self):
         return (
             self.create_torrent_job,
             self.screenshots_job,
             self.upload_screenshots_job,
+            self.poster_job,
             self.mediainfo_job,
             self.imdb_job,
             self.tmdb_job,
@@ -69,21 +74,16 @@ class DummyTrackerJobs(base.TrackerJobsBase):
     @cached_property
     def category_job(self):
         if not self.options['skip_category']:
-
-            def select_release_category(_):
-                user_approved_release_name = self.release_name
-                _log.debug('Setting type: %r', user_approved_release_name.type)
-                if user_approved_release_name.type:
-                    self.category_job.focused = user_approved_release_name.type
-
-            self.release_name_job.signal.register('output', select_release_category)
-
-            choices = [(str(t).capitalize(), t) for t in ReleaseType if t]
             return jobs.dialog.ChoiceJob(
-                name='category',
+                name=self.get_job_name('category'),
                 label='Category',
-                choices=choices,
-                **self.common_job_args,
+                condition=self.make_job_condition('category_job'),
+                choices=(
+                    (str(typ).capitalize(), typ)
+                    for typ in ReleaseType if typ
+                ),
+                autodetected=self.release_name.type,
+                **self.common_job_args(),
             )
 
 
