@@ -2,7 +2,7 @@
 Concrete :class:`~.base.TrackerJobsBase` subclass for NBL
 """
 
-from ... import jobs
+from ... import jobs, utils
 from ...utils import cached_property
 from .. import base
 
@@ -30,10 +30,21 @@ class NblTrackerJobs(base.TrackerJobsBase):
                 ('Season', '3'),
                 ('Episode', '1'),
             ),
-            autodetected=str(self.release_name.type).capitalize(),
+            autodetected=self.autodetected_category,
             **self.common_job_args(),
         )
 
+    @cached_property
+    def autodetected_category(self):
+        if self.release_name.type is utils.release.ReleaseType.season:
+            return 'Season'
+        else:
+            # Sometimes a series is continued or finalized as one or more
+            # movies. We submit them as episodes.
+            # TODO: Once the API supports it, we should add the special tag.
+            # Example: https://www.tvmaze.com/shows/3646/alien-nation/episodes
+            return 'Episode'
+
     @property
     def post_data(self):
         return {
