@@ -408,6 +408,6 @@ class CommandBase(abc.ABC):
         ``config.main.cache_directory`` otherwise.
         """
         if hasattr(self.args, 'CONTENT') or hasattr(self.args, 'RELEASE'):
-            return os.path.join(self.home_directory, '.joboutput')
+            return os.path.join(self.home_directory, '.cache')
         else:
             return self.config['config']['main']['cache_directory']
