@@ -1,4 +1,3 @@
-from prompt_toolkit.application import get_app
 from prompt_toolkit.layout.containers import (DynamicContainer, HSplit, VSplit,
                                               Window)
 from prompt_toolkit.layout.controls import FormattedTextControl
@@ -190,7 +189,7 @@ class _SearchResults(DynamicContainer):
         self._year_width = 4
         self._type_width = 6
         self._title_width = width - self._year_width - self._type_width - 2
-        self._activity_indicator = widgets.ActivityIndicator(callback=self._activity_indicator_callback)
+        self._activity_indicator = widgets.ActivityIndicator()
         super().__init__(
             lambda: Window(
                 content=FormattedTextControl(self._get_text_fragments, focusable=False),
@@ -238,9 +237,6 @@ class _SearchResults(DynamicContainer):
     def select_last(self):
         self._focused_index = len(self._results) - 1
 
-    def _activity_indicator_callback(self, string):
-        get_app().invalidate()
-
     def _get_text_fragments(self):
         if self.is_searching:
             return [('class:dialog.search.results', self._activity_indicator.text)]
