@@ -5,10 +5,11 @@ Scene release search and verification
 from ... import utils
 from .. import release
 from ..types import SceneCheckResult
-from . import predbde, predbovh, srrdb
-from .base import MultiPredbApi, PredbApiBase
+from . import corruptnet, predbde, predbovh, srrdb
+from .base import PredbApiBase
 from .common import (assert_not_abbreviated_filename, is_abbreviated_filename,
                      is_mixed_season_pack)
+from .multi import MultiPredbApi
 from .query import SceneQuery
 
 
