@@ -446,8 +446,8 @@ def has_dual_audio(path, default=NO_DEFAULT_VALUE):
         if 'commentary' not in track.get('Title', '').lower():
             language = track.get('Language', '')
             if language:
-                languages.add(language.casefold())
-    if len(languages) > 1 and 'en' in languages:
+                languages.add(language.casefold()[:2])
+    if len(languages) > 1:
         return True
     else:
         return False
