@@ -5,10 +5,17 @@ Abstract base class for online databases
 import abc
 import asyncio
 import copy
+import re
+import string
+
+import unidecode
 
 from .. import country
 from .common import Query
 
+import logging  # isort:skip
+_log = logging.getLogger(__name__)
+
 
 class WebDbApiBase(abc.ABC):
     """
@@ -144,31 +151,105 @@ class WebDbApiBase(abc.ABC):
         """Return short plot description"""
 
     @abc.abstractmethod
-    async def title_english(self, id):
-        """
-        Return English title if it differs from original title or empty string
-
-        If the English title if is too similar to the original title, return an
-        empty string. You should use :meth:`title_original` in that case.
-
-        Titles are normalized (casefolded, stripped, etc) before they are
-        compared, and neither one must be contained in the other.
-
-        For example, if the original title is "Foo" and the English title is
-        "The Foo", the titles are considered too similar and an empty string is
-        returned. But if the Original title is "Le Feu", "The Foo" is returned.
-        """
+    async def _title_original(self, id):
+        """Return original title"""
 
     @abc.abstractmethod
+    async def _titles_english(self, id):
+        """
+        Return sequence of English titles (e.g. for different
+        English-speaking countries)
+
+        :meth:`title_english` picks one that is not too similar to the original
+        title.
+        """
+
     async def title_original(self, id):
         """
-        Return original title (e.g. non-English)
+        Return original title
 
-        Return the original title if one is found and it is sufficiently
-        different from the English title (also see :meth:`title_english`).
-        Otherwise, return the English title, assuming it is an English-language
-        movie or series.
+        See also :meth:`title_english`.
         """
+        if id:
+            return await self._title_original(id)
+        return ''
+
+    async def title_english(self, id, *, default_to_original=False):
+        """
+        Return English title (AKA) or empty string
+
+        If the English title is too similar to the original title, return an
+        empty string.
+
+        Titles are considered too similar if they are equal or either one
+        contains the other after normalization.
+
+        Titles are normalized by casefolding, removing whitespace, translating
+        roman numerals to arabic, etc.
+
+        For example, if the original title is "Föö & Bár II" and the English
+        title is "The Foo and Bar 2", the titles are too similar.
+
+        :param default_to_original: Instead of defaulting to an empty string if
+            no appropriate English title is found, default to the original title
+        """
+        if id:
+            english_titles = await self._titles_english(id)
+            original_title = await self._title_original(id)
+            for english_title in english_titles:
+                # Don't return English title if it is similar to original title
+                # (e.g. english_title="The Foo", original_title="Föó")
+                if not self._titles_are_similar(english_title, original_title):
+                    _log.debug('Using English title: %r', english_title)
+                    return english_title
+                else:
+                    _log.debug('English title is too similar to original: %r == %r', english_title, original_title)
+
+            # Return the first English title if we can't return empty string
+            if default_to_original:
+                _log.debug('Defaulting to original title: %r', original_title)
+                return original_title
+
+        return ''
+
+    def _titles_are_similar(self, a, b):
+        """Whether normalized `a` contains normalized `b` or vice versa"""
+        an = self._normalize_title(a)
+        bn = self._normalize_title(b)
+        return an and bn and (an in bn or bn in an)
+
+    def _normalize_title(self, title):
+        """Return casefolded `title` normalized punctuation, whitespace, etc"""
+        # Replace special characters with similar ASCII
+        title = title.replace('&', 'and')
+        title = unidecode.unidecode(title)
+
+        # Remove all punctuation
+        title = re.sub(rf'[{string.punctuation}]+', '', title)
+
+        # Deduplicate whitespace into spaces (U+0020)
+        title = ' '.join(title.split())
+
+        # Remove difference between arabic and roman numbers
+        def normalize_part(match):
+            num = match.group(1)
+            if num.isdigit():
+                num_arabic = num
+                num_roman = int(num) * 'I'
+            else:
+                num_arabic = len(num)
+                num_roman = num
+            return f'{num_arabic}/{num_roman}'
+
+        title = re.sub(r'\b((?i:I+|\d+))\b', normalize_part, title)
+
+        # Remove all whitespace
+        title = ''.join(title.split())
+
+        # Case-insensitivize
+        title = title.casefold()
+
+        return title
 
     @abc.abstractmethod
     async def type(self, id):
