@@ -4,9 +4,6 @@ API for imdb.com
 
 import functools
 import re
-import string
-
-import unidecode
 
 from ... import utils
 from ..types import ReleaseType
@@ -285,104 +282,22 @@ class ImdbApi(WebDbApiBase):
 
         return ''
 
-    async def title_english(self, id, allow_empty=True):
-        if id:
-            akas = await self._get_akas(id)
-            original_title = akas.get('(original title)', '')
-            for regex in self._english_akas_keys:
-                for key, english_title in akas.items():
-                    # _log.debug('Matching: %-40r against %s', key, regex.pattern)
-                    if regex.search(key):
-                        # Return the first match if we can't return an empty string
-                        if not allow_empty:
-                            # _log.debug('  Using first match: %r', english_title)
-                            return english_title
+    async def _title_original(self, id):
+        akas = await self._get_akas(id)
+        return akas.get('(original title)', '')
 
-                        # Don't return English title if it is similar to
-                        # original title (e.g. english_title="The Foo",
-                        # original_title="Föó")
-                        if not self._titles_are_similar(english_title, original_title):
-                            # _log.debug('  Sufficiently different original title: %r != %r', original_title, english_title)
-                            return english_title
-                        # else:
-                        #     _log.debug('  Similar to original title %r == %r', original_title, english_title)
-        return ''
+    async def _titles_english(self, id):
+        english_titles = []
+        # Make a list of English titles
+        akas = await self._get_akas(id)
+        for regex in self._english_akas_keys:
+            for key, english_title in akas.items():
+                # _log.debug('Matching: %-40r against %s', key, regex.pattern)
+                if regex.search(key):
+                    _log.debug('Found English title: %r: %s', key, english_title)
+                    english_titles.append(english_title)
+        return english_titles
 
-    async def title_original(self, id):
-        if id:
-            akas = await self._get_akas(id)
-            original_title = akas.get('(original title)', '')
-            english_title = await self.title_english(id, allow_empty=False)
-            if original_title:
-                if not self._titles_are_similar(original_title, english_title):
-                    # _log.debug('  Sufficiently different English title: %r != %r', english_title, original_title)
-                    return original_title
-                # else:
-                #     _log.debug('Similar to English title %r: %r', english_title, original_title)
-            else:
-                # Default to getting title from link to main page
-                # _log.debug('No original title in AKAs found')
-                soup = await self._get_soup(f'title/{id}/releaseinfo')
-                title_tag = soup.find(class_='subpage_title_block__right-column')
-                if title_tag:
-                    a_tag = title_tag.find('a', href=re.compile(r'/title/tt'))
-                    if a_tag:
-                        return a_tag.string
-
-            _log.debug('Defaulting to English title: %r', english_title)
-            return english_title
-        return ''
-
-    def _titles_are_similar(self, a, b):
-        """Whether normalized `a` contains normalized `b` or vice versa"""
-        an = self._normalize_title(a)
-        bn = self._normalize_title(b)
-        return an and bn and (an in bn or bn in an)
-
-    def _normalize_title(self, title):
-        """Return casefolded `title` normalized punctuation, whitespace, etc"""
-        # Replace special characters with similar ASCII
-        title = title.replace('&', 'and')
-        title = unidecode.unidecode(title)
-
-        # Remove all punctuation
-        title = re.sub(rf'[{string.punctuation}]+', '', title)
-
-        # Deduplicate whitespace into spaces (U+0020)
-        title = ' '.join(title.split())
-
-        # Remove difference between arabic and roman numbers
-        def normalize_part(match):
-            num = match.group(1)
-            if num.isdigit():
-                num_arabic = num
-                num_roman = int(num) * 'I'
-            else:
-                num_arabic = len(num)
-                num_roman = num
-            return f'{num_arabic}/{num_roman}'
-
-        title = re.sub(r'\b((?i:I+|\d+))\b', normalize_part, title)
-
-        # Remove all whitespace
-        title = ''.join(title.split())
-
-        # Case-insensitivize
-        title = title.casefold()
-
-        return title
-
-    _ignored_akas_keys = (
-        re.compile(r'\(TV title\)$'),
-        re.compile(r'\(alternative spelling\)$'),
-        re.compile(r'\(dubbed version\)$'),
-        re.compile(r'\(literal title\)$'),
-        re.compile(r'\(original script title\)$'),
-        re.compile(r'\([\w ]*short title\)$'),  # ([informal|...?] short title)
-        re.compile(r'\(video box title\)$'),
-        re.compile(r'\(working title\)$'),
-        re.compile(r'\(long title\)$'),
-    )
     _english_akas_keys = (
         re.compile(r'^USA.*English'),
         re.compile(r'^USA$'),
@@ -405,18 +320,30 @@ class ImdbApi(WebDbApiBase):
 
             title_tag = item.find('td', class_='aka-item__title')
             title = ''.join(title_tag.stripped_strings).strip()
-            # _log.debug('Found %r = %r', key, title)
 
             if title:
                 if not any(regex.search(key) for regex in self._ignored_akas_keys):
+                    # _log.debug('AKA: %r -> %r', key, title)
                     akas[key] = title
             #     else:
-            #         _log.debug('Ignoring AKA: %r -> %r', key, title)
+            #         _log.debug('AKA not wanted: %r -> %r', key, title)
             # else:
-            #     _log.debug('Ignoring empty title: %r -> %r', key, title)
+            #     _log.debug('AKA empty: %r -> %r', key, title)
 
         return akas
 
+    _ignored_akas_keys = (
+        re.compile(r'\(TV title\)$'),
+        re.compile(r'\(alternative spelling\)$'),
+        re.compile(r'\(dubbed version\)$'),
+        re.compile(r'\(literal title\)$'),
+        re.compile(r'\(original script title\)$'),
+        re.compile(r'\([\w ]*short title\)$'),  # ([informal|...?] short title)
+        re.compile(r'\(video box title\)$'),
+        re.compile(r'\(working title\)$'),
+        re.compile(r'\(long title\)$'),
+    )
+
     async def type(self, id):
         if id:
             soup = await self._get_soup(f'title/{id}/')
