@@ -11,7 +11,6 @@ from .. import html, http
 from ..types import ReleaseType
 from . import common
 from .base import WebDbApiBase
-from .imdb import ImdbApi
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -27,10 +26,6 @@ class TvmazeApi(WebDbApiBase):
 
     _url_base = 'http://api.tvmaze.com'
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self._imdb = ImdbApi()
-
     def sanitize_query(self, query):
         """Set :attr:`~.common.Query.type` to :attr:`~.types.ReleaseType.unknown`"""
         query = super().sanitize_query(query)
@@ -79,7 +74,7 @@ class TvmazeApi(WebDbApiBase):
             return info
 
     async def _get_show(self, id):
-        url = f'{self._url_base}/shows/{id}?embed[]=cast&embed[]=crew'
+        url = f'{self._url_base}/shows/{id}?embed[]=cast&embed[]=crew&embed[]=akas'
         return await self._get_json(url)
 
     async def cast(self, id):
@@ -160,19 +155,39 @@ class TvmazeApi(WebDbApiBase):
             return _get_summary(show)
         return ''
 
-    async def title_english(self, id):
-        if id:
-            imdb_id = await self.imdb_id(id)
-            if imdb_id:
-                return await self._imdb.title_english(imdb_id)
-        return ''
+    async def _title_original(self, id):
+        akas = await self._get_akas(id)
+        return akas['ORIGIN']
 
-    async def title_original(self, id):
-        if id:
-            imdb_id = await self.imdb_id(id)
-            if imdb_id:
-                return await self._imdb.title_original(imdb_id)
-        return ''
+    async def _titles_english(self, id):
+        akas = await self._get_akas(id)
+        return akas.values()
+
+    async def _get_akas(self, id):
+        show = await self._get_show(id)
+        akas = {}
+        for aka in show['_embedded']['akas']:
+            # `aka['country']` may also be `None`, which indicates the
+            # original country
+            country = aka.get('country')
+            if country is None:
+                akas['ORIGIN'] = aka['name']
+            else:
+                code = country.get('code', '')
+                if code in self._english_country_codes:
+                    akas['code'] = aka['name']
+
+        if 'ORIGIN' not in akas:
+            akas['ORIGIN'] = show['name']
+
+        return akas
+
+    _english_country_codes = (
+        'US',
+        'UK',
+        'AU',
+        'NZ',
+    )
 
     async def type(self, id):
         # TVmaze does not support movies and we can't distinguish between season
@@ -282,9 +297,9 @@ def _get_genres(show):
         return ()
 
 def _get_countries(show):
-    network = show.get('network', None)
-    if network:
-        country = network.get('country', None)
+    info = show.get('network', None) or show.get('webChannel', None)
+    if info:
+        country = info.get('country', None)
         if country:
             name = country.get('name', None)
             if name:
